# ptcime
Small time tracker built on python.

## Installation

```bash
pip install ptcime
```

## Usage


Start tracking time:
```bash
ptcime start
```
Stop tracking time and log currently worked on:
```bash    
ptcime stop
```

Log currently worked time:
```bash
ptcime current
```

Log day work time:
```bash
ptcime day
```
Log week work time:
```bash
ptcime week
```
